@@ -34,7 +34,9 @@ class FaceAnalysis:
                 #print('ignore:', onnx_file)
                 continue
             model = model_zoo.get_model(onnx_file)
-            if allowed_modules is not None and model.taskname not in allowed_modules:
+            if model is None:
+                print('model not recognized:', onnx_file)
+            elif allowed_modules is not None and model.taskname not in allowed_modules:
                 print('model ignore:', onnx_file, model.taskname)
                 del model
             elif model.taskname not in self.models and (allowed_modules is None or model.taskname in allowed_modules):
@@ -96,6 +98,9 @@ class FaceAnalysis:
                         color = (0, 255, 0)
                     cv2.circle(dimg, (kps[l][0], kps[l][1]), 1, color,
                                2)
+            if face.gender is not None and face.age is not None:
+                cv2.putText(dimg,'%s,%d'%(face.sex,face.age), (box[0]-1, box[1]-4),cv2.FONT_HERSHEY_COMPLEX,0.7,(0,255,0),1)
+
             #for key, value in face.items():
             #    if key.startswith('landmark_3d'):
             #        print(key, value.shape)
